@@ -1,4 +1,5 @@
 import os
+import json
 import pkgutil
 from functools import reduce
 from collections import defaultdict
@@ -29,6 +30,7 @@ class Evalscript:
         datacube_definition_directory="javascript_datacube",
         output_dimensions=None,
         encode_result=True,
+        bands_metadata=[],
     ):
         self.input_bands = input_bands
         self.nodes = nodes
@@ -42,6 +44,7 @@ class Evalscript:
         self.temporal_dimension_name = temporal_dimension_name
         self._output_dimensions = output_dimensions
         self.encode_result = encode_result
+        self.bands_metadata = bands_metadata
 
     def write(self):
         if self.input_bands is None:
@@ -59,12 +62,14 @@ function setup() {{
 }}
 {self.write_update_output()}
 {self.write_common_definition()}
+{self.write_ndarray_definition()}
 {self.write_datacube_definition()}
 {newline.join([node.write_function() for node in self.nodes])}
-function evaluatePixel(samples) {{
+function evaluatePixel(samples, scenes) {{
     {self.write_datacube_creation()}
     {(newline + tab).join([node.write_call() for node in self.nodes])}
-    return {self.write_output_variable()}{".encodeData()" if self.encode_result else '.flattenToArray()'}
+    const finalOutput = {self.write_output_variable()}{".encodeData()" if self.encode_result else '.flattenToArray()'}
+    return Array.isArray(finalOutput) ? finalOutput : [finalOutput];
 }}
 """
 
@@ -74,8 +79,11 @@ function evaluatePixel(samples) {{
     def write_common_definition(self):
         return pkgutil.get_data("pg_to_evalscript", f"javascript_common/common.js").decode("utf-8")
 
+    def write_ndarray_definition(self):
+        return pkgutil.get_data("pg_to_evalscript", f"javascript_datacube/ndarray.js").decode("utf-8")
+
     def write_datacube_creation(self):
-        return f"let {self.initial_data_name} = new DataCube(samples, '{self.bands_dimension_name}', '{self.temporal_dimension_name}', true)"
+        return f"let {self.initial_data_name} = new DataCube(samples, '{self.bands_dimension_name}', '{self.temporal_dimension_name}', true, {json.dumps(self.bands_metadata)}, scenes)"
 
     def write_update_output(self):
         if self._output_dimensions is None:
@@ -90,7 +98,7 @@ function evaluatePixel(samples) {{
             lambda x, y: x * y, sizes_without_original_temporal_dimensions, 1
         )
         collection_scenes_length = "* collection.scenes.length" * number_of_original_temporal_dimensions
-        number_of_final_dimensions = len(self._output_dimensions)
+        number_of_final_dimensions = len(self._output_dimensions) + 1 if self.encode_result else 0
         return f"""
 function updateOutput(outputs, collection) {{
     Object.values(outputs).forEach((output) => {{
